<?php
$include_path = ini_get('include_path');
ini_set('include_path', $include_path . ':' . dirname(dirname(dirname(__FILE__))));

require_once 'PHPUnit/Framework.php';
require_once 'Xpw/System/Base.php';
require_once 'Xpw/Reflection/Class.php';

class ClassReflectionExample extends Xpw_System_Base
{
	const A = '1';
	
	const B = true;
	
	public static $q;
	
	private $_a;
	
	private $_b;
	
	protected $_c;
	
	public $d;
	
	public function aPropertySet($value)
	{
		$this->_a = $value;
	}
	
	public function aPropertyGet()
	{
		return $this->_a;
	}
	
	public function aPropertyIsset()
	{
		return isset($this->_a);
	}
	
	public function aPropertyUnset()
	{
		unset($this->_a);	
	}
	
	protected function bPropertySet($value)
	{
		$this->_b = $value;
	}
	
	protected function bPropertyGet()
	{
		return $this->_b;
	}
	
	public static function asd()
	{
		
	}
	
	public function qwerty()
	{
		
	}
}

class ClassReflectionTest extends PHPUnit_Framework_TestCase
{
	/**
	 * Class reflection.
	 *
	 * @var Xpw_Reflection_Class
	 */
	private $_classReflection;
	
	protected function SetUp()
	{
		$this->_classReflection = new Xpw_Reflection_Class('ClassReflectionExample');
	}
	
	public function testConstants()
	{
		$constants = $this->_classReflection->getConstants();
		$this->assertEquals(2, count($constants));
		$this->assertTrue($constants['B']);
		$aConstant = $this->_classReflection->getConstant('A');
		$this->assertEquals('1', $aConstant);
	}
	
	public function testProperties()
	{
		$staticProperties = $this->_classReflection->getProperties(ReflectionProperty::IS_STATIC);
		$this->assertEquals(1, count($staticProperties));
		$this->assertTrue($staticProperties[0]->isStatic());
		$this->assertTrue($staticProperties[0]->isPublic());
		$this->assertEquals('q', $staticProperties[0]->getName());
		$properties = $this->_classReflection->getProperties();
		$this->assertEquals(5, count($properties));
		$dProperty = $this->_classReflection->getProperty('d');
		$this->assertTrue($dProperty->isPublic());
	}
	
	public function testComplexProperties()
	{
		$complexProperties = $this->_classReflection->getComplexProperties();
		$this->assertEquals(2, count($complexProperties));
		$bComplexProperty = $this->_classReflection->getComplexProperty('b');
		$this->assertFalse($bComplexProperty->hasIsset());
		$this->assertFalse($bComplexProperty->hasUnset());
	}
	
	public function textMethods()
	{
		$staticMethods = $this->_classReflection->getMethods(ReflectionMethod::IS_STATIC);
		$this->assertEquals(1, count($staticMethods));
		$this->assertTrue($staticMethods[0]->isStatic());
		$this->assertEquals('asd', $staticMethods[0]->getName());
		$methods = $this->_classReflection->getMethods();
		$this->assertEquals(2, count($methods));
		$qwertyMethod = $this->_classReflection->getMethod('qwerty');
		$this->assertTrue($qwertyMethod->isPublic());
		$this->assertEquals(0, count($qwertyMethod->getParameters()));
	}
}
?>