<?php
$include_path = ini_get('include_path');
ini_set('include_path', $include_path . ':' . dirname(dirname(dirname(__FILE__))));

require_once 'PHPUnit/Extensions/ExceptionTestCase.php';
require_once 'Xpw/System/Base.php';
require_once 'Xpw/Reflection/Exception.php';
require_once 'Xpw/Reflection/ComplexProperty.php';

class ComplexPropertyReflectionExample extends Xpw_System_Base 
{
	private $_a;
	
	private $_b;
	
	public function aPropertySet($value)
	{
		$this->_a = $value;
	}
	
	public function aPropertyGet()
	{
		return $this->_a;
	}
	
	public function aPropertyIsset()
	{
		return isset($this->_a);
	}
	
	public function aPropertyUnset()
	{
		unset($this->_a);	
	}
	
	protected function bPropertySet($value)
	{
		$this->_b = $value;
	}
	
	protected function bPropertyGet()
	{
		return $this->_b;
	}
}

class ComplexPropertyReflectionTest extends PHPUnit_Extensions_ExceptionTestCase
{
	public function testPublicComplexProperty()
	{
		$reflection = new Xpw_Reflection_ComplexProperty('ComplexPropertyReflectionExample', 'a');
		$aObject = new ComplexPropertyReflectionExample();
		$aObject->a = 2;
		$this->assertEquals(2, $reflection->getValue($aObject));
		$reflection->setValue($aObject, 3);
		$this->assertEquals(3, $aObject->a);
		$this->assertTrue($reflection->issetValue($aObject));
		$reflection->unsetValue($aObject);
		$this->assertFalse($reflection->issetValue($aObject));
	}
	
	public function testProtectedComplexProperty()
	{
		$this->setExpectedException('Xpw_Reflection_Exception');
		$reflection = new Xpw_Reflection_ComplexProperty('ComplexPropertyReflectionExample', 'b');
		$aObject = new ComplexPropertyReflectionExample();
		$reflection->getValue($aObject);
		$reflection->setValue($aObject, 1);
	}
}
?>