<?php
/**
 * XPW Framework
 *
 * LICENSE
 *
 * This source file is subject to the LGPLv3 license that is bundled
 * with this package in the file LICENSE.
 * It is also available through the world-wide-web at this URL:
 * http://xpw.ukrsoftsolutions.com/license
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@xpw.ukrsoftsolutions.com so we can send you a copy immediately.
 *
 * @category   XPW
 * @package    Xpw_System_Base
 * @copyright  Copyright (c) 2008 UkrSoftSolutions (http://www.ukrsoftsolutions.com)
 * @version    1.0beta1
 * @license    http://xpw.ukrsoftsolutions.com/license     LGPLv3 License
 */

/**
 * @category   XPW
 * @package    Xpw_System_Base
 * @copyright  Copyright (c) 2008 UkrSoftSolutions (http://www.ukrsoftsolutions.com)
 * @license    http://xpw.ukrsoftsolutions.com/license     LGPLv3 License
 */
abstract class Xpw_System_Base
{
	/**
	 * Creates new object instance.
	 *
	 */
	public function __construct()
	{
	}
	
	/**
	 * Sets value of the undefined member
	 *
	 * @param string $name
	 * @param mixed $value
	 */
	public function __set($name, $value)
	{
		if (method_exists($this, $name . 'PropertySet'))
			call_user_method($name . 'PropertySet', $this, $value);
		return;
	}
	
	/**
	 * Gets value of the undefined member
	 *
	 * @param string $name
	 * @return mixed
	 */
	public function __get($name)
	{
		if (method_exists($this, $name . 'PropertyGet'))
			return call_user_method($name . 'PropertyGet', $this);
	}
	
	/**
	 * Whether undefined member is set
	 *
	 * @param string $name
	 * @return bool
	 */
	public function __isset($name)
	{
		if (method_exists($this, $name . 'PropertyIsset'))
			return call_user_method($name . 'PropertyIsset', $this);
	}
	
	/**
	 * Unsets undefined member
	 *
	 * @param string $name
	 */
	public function __unset($name)
	{
		if (method_exists($this, $name . 'PropertyUnset'))
			call_user_method($name . 'PropertyUnset', $this);
	}
}
?>